==> wechatpy-1.8.11.tar.gz: wechatpy-1.8.11/wechatpy/enterprise/client/api/__init__.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

from wechatpy.enterprise.client.api.agent import WeChatAgent  # NOQA
from wechatpy.enterprise.client.api.appchat import WeChatAppChat  # NOQA
from wechatpy.enterprise.client.api.batch import WeChatBatch  # NOQA
from wechatpy.enterprise.client.api.calendar import WeChatCalendar  # NOQA
from wechatpy.enterprise.client.api.chat import WeChatChat  # NOQA
from wechatpy.enterprise.client.api.department import WeChatDepartment  # NOQA
from wechatpy.enterprise.client.api.external_contact import WeChatExternalContact  # NOQA
from wechatpy.enterprise.client.api.jsapi import WeChatJSAPI  # NOQA
from wechatpy.enterprise.client.api.material import WeChatMaterial  # NOQA
from wechatpy.enterprise.client.api.media import WeChatMedia  # NOQA
from wechatpy.enterprise.client.api.menu import WeChatMenu  # NOQA
from wechatpy.enterprise.client.api.message import WeChatMessage  # NOQA
from wechatpy.enterprise.client.api.misc import WeChatMisc  # NOQA
from wechatpy.enterprise.client.api.oauth import WeChatOAuth  # NOQA
from wechatpy.enterprise.client.api.schedule import WeChatSchedule  # NOQA
from wechatpy.enterprise.client.api.service import WeChatService  # NOQA
from wechatpy.enterprise.client.api.shakearound import WeChatShakeAround  # NOQA
from wechatpy.enterprise.client.api.tag import WeChatTag  # NOQA
from wechatpy.enterprise.client.api.user import WeChatUser  # NOQA
from wechatpy.enterprise.client.api.OA import WeChatOA

==> wechatpy-1.8.18.tar.gz: wechatpy-1.8.18/wechatpy/enterprise/client/api/__init__.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

from wechatpy.enterprise.client.api.agent import WeChatAgent  # NOQA
from wechatpy.enterprise.client.api.appchat import WeChatAppChat  # NOQA
from wechatpy.enterprise.client.api.batch import WeChatBatch  # NOQA
from wechatpy.enterprise.client.api.calendar import WeChatCalendar  # NOQA
from wechatpy.enterprise.client.api.chat import WeChatChat  # NOQA
from wechatpy.enterprise.client.api.department import WeChatDepartment  # NOQA
from wechatpy.enterprise.client.api.external_contact import WeChatExternalContact  # NOQA
from wechatpy.enterprise.client.api.external_contact_group_chat import WeChatExternalContactGroupChat  # NOQA
from wechatpy.enterprise.client.api.jsapi import WeChatJSAPI  # NOQA
from wechatpy.enterprise.client.api.material import WeChatMaterial  # NOQA
from wechatpy.enterprise.client.api.media import WeChatMedia  # NOQA
from wechatpy.enterprise.client.api.menu import WeChatMenu  # NOQA
from wechatpy.enterprise.client.api.message import WeChatMessage  # NOQA
from wechatpy.enterprise.client.api.misc import WeChatMisc  # NOQA
from wechatpy.enterprise.client.api.oauth import WeChatOAuth  # NOQA
from wechatpy.enterprise.client.api.schedule import WeChatSchedule  # NOQA
from wechatpy.enterprise.client.api.service import WeChatService  # NOQA
from wechatpy.enterprise.client.api.shakearound import WeChatShakeAround  # NOQA
from wechatpy.enterprise.client.api.tag import WeChatTag  # NOQA
from wechatpy.enterprise.client.api.user import WeChatUser  # NOQA
from wechatpy.enterprise.client.api.OA import WeChatOA
